@@ -6,4 +6,6 @@ class TextElementType(Enum):
     SPAN = 1
     SENT = 2
     BLOCK = 3
-    DOC = 4
\ No newline at end of file
+    DOC = 4
+    CONV = 5
+    COMM = 6
\ No newline at end of file
