@@ -39,9 +39,34 @@ LINKS = {
                     "version": "https://nextcloud.readerbench.com/index.php/s/GRsJP7yFreeicaR/download"
                 }
             },
+            'sentiment': {
+                'small': {
+                    "link": "https://nextcloud.readerbench.com/index.php/s/QNYRtoCEQgri499/download",
+                    "version": "https://nextcloud.readerbench.com/index.php/s/CF5TmPeEKFNib4H/download"
+                },
+                'base': {
+                    "link": "https://nextcloud.readerbench.com/index.php/s/kC98HTJbPmsXxBj/download",
+                    "version": "https://nextcloud.readerbench.com/index.php/s/ix5FRQHEbaP8CFw/download"
+                },
+                'large': {
+                    "link": "https://nextcloud.readerbench.com/index.php/s/pHXqLQ8HXar44WT/download",
+                    "version": "https://nextcloud.readerbench.com/index.php/s/aEnbRMiscMjRxcL/download"
+                },
+            },
+            
             'readme': {
                 "link": "https://nextcloud.readerbench.com/index.php/s/Sj94ysrmDDxX8YH/download",
                 "version": "https://nextcloud.readerbench.com/index.php/s/QXd8847qLz5tNAa/download"
+            },
+            'gec': {
+                "transformer_768": {
+                    "link": "https://nextcloud.readerbench.com/index.php/s/CPAS95MNyZGsKas/download",
+                    "version": "https://nextcloud.readerbench.com/index.php/s/GaETKtdRkFmpDDH/download"
+                },
+                'transformer_64': {
+                    'version': 'https://nextcloud.readerbench.com/index.php/s/W9FB2dX5ykHqiLk/download',
+                    'link': 'https://nextcloud.readerbench.com/index.php/s/ZrP2mZszCXim4EW/download'
+                }
             }
         },
         'spacy': {
